@@ -1,5 +1,6 @@
 from __future__ import division, print_function
 import hashlib
+from io import open
 import json
 import logging
 import os
@@ -8,12 +9,11 @@ import shutil
 import subprocess
 import tempfile
 import sys
-import six
-from six.moves.urllib.parse import urlparse
 
 from .basic import HandlerResult, SourceHandler
 from .exceptions import InvalidOption, NoSuchCharm
-from io import open
+from .. import six
+from ..six.moves.urllib.parse import urlparse
 
 
 SUPPORTED_CHANNELS = ('unpublished', 'edge', 'beta', 'candidate', 'stable')
@@ -112,7 +112,7 @@ class CharmStoreHandler(SourceHandler):
 
         path = os.path.join(dest, self.metadata_filename)
         with open(path, 'w') as metadata_file:
-            metadata_file.write(self._source_with_channel(self.charmstore_url, channel))
+            metadata_file.write(six.u(self._source_with_channel(self.charmstore_url, channel)))
 
     @staticmethod
     def _source_with_channel(url, channel):
@@ -169,9 +169,8 @@ class _CharmStoreHttpDownloader(object):
         # Verify SHA
         expected_sha = req.headers['Content-Sha384']
         if calculated_sha != expected_sha:
-            raise requests.HTTPError("SHA of downloaded charm {} didn't match " +
-                                     "expected SHA {}".format(calculated_sha,
-                                                              expected_sha))
+            raise requests.HTTPError("SHA of downloaded charm {} didn't match "
+                                     "expected SHA {}".format(calculated_sha, expected_sha))
 
         return zip_path
 
