@@ -212,7 +212,7 @@ class TestHttpFileHandler(TestCase):
         with patch('codetree.handlers.basic.open', _open, create=True):
             self.assertTrue(hh.get(destfile, {}))
         self.assertFalse(_unlink.called)
-        _open.assert_called_with(destfile, "w")
+        _open.assert_called_with(destfile, "wb")
         _urlopen.assert_called_with(HttpURLs[0])
 
     @patch('codetree.handlers.basic.os.unlink')
@@ -248,7 +248,7 @@ class TestHttpFileHandler(TestCase):
         with patch('codetree.handlers.basic.open', _open, create=True):
             self.assertTrue(hh.get(destfile, options={"overwrite": True}))
         _unlink.assert_called_with(destfile)
-        _open.assert_called_with(destfile, "w")
+        _open.assert_called_with(destfile, "wb")
         _urlopen.assert_called_with(HttpURLs[0])
 
     @patch('codetree.handlers.basic.os.unlink')
