@@ -260,6 +260,12 @@ class TestConfig(TestCase):
             }
         self.assertEqual(collect_info["hashes"], expected_hashes)
 
+    def test_empty_collect_file(self):
+        # Test that an empty collect file (or a file with comments only)
+        # is handled correctly and doesn't throw an error due to 0 workers.
+        collect_config = Config('tests/test_data/comments_only')
+        self.assertEqual(collect_config.build(), [])
+
 
 class TestConfigResults(TestCase):
     def test_true(self):
