@@ -93,7 +93,14 @@ class TestGitSourceHandler(TestCase):
         d = mkdtemp('', 'git-handler')
         try:
             wd = os.path.join(d, 'test')
-            gh.get(wd, {'revno': 'branch-B'})
+            ret = gh.get(wd, {'branch': 'branch-B'})
+            self.assertTrue(ret.success)
+            with open(os.path.join(wd, 'file'), "r") as f:
+                c = f.read().strip()
+            self.assertEqual('branch B', c)
+            # Get with branch another time to validate the idempotency
+            ret = gh.get(wd, {'branch': 'branch-B'})
+            self.assertTrue(ret.success)
             with open(os.path.join(wd, 'file'), "r") as f:
                 c = f.read().strip()
             self.assertEqual('branch B', c)
